CborMultiDimensionalArray class

A CBOR Multi-dimensional Array (RFC 8746).

Implemented types

Constructors

CborMultiDimensionalArray({required List<int> dimensions, required CborValue data, List<int> tags = const [CborTag.multiDimensionalArray]})
const
CborMultiDimensionalArray.fromTypedArray(List<int> dimensions, CborTypedArray data, {List<int>? tags})
factory
CborMultiDimensionalArray.fromValues(List<int> dimensions, List<CborValue> values, {List<int>? tags})
factory

Properties

data CborValue
final
dimensions List<int>
final
expectedConversion → JsonBytesEncoding?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
Additional tags provided to the value.
final

Methods

encode(EncodeSink sink) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({Object? substituteValue, bool allowMalformedUtf8 = false}) Object?
Transform this into a JSON encodable value.
inherited
toJsonInternal(Set<Object> cyclicCheck, ToJsonOptions o) Object?
toObject({bool parseDateTime = true, bool parseUri = true, bool decodeBase64 = false, bool allowMalformedUtf8 = false}) Object?
Transforms the CborValue into a Dart object.
inherited
toObjectInternal(Set<Object> cyclicCheck, ToObjectOptions o) Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited