WalletFactory class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromHdWallet(NetworkId networkId, HdWallet hdWallet) Future<CardanoWallet>
fromMnemonic(NetworkId networkId, List<String> mnemonic, {int accountIndex = defaultAccountIndex}) Future<CardanoWallet>
fromSeed(NetworkId networkId, ByteList seed) Future<CardanoWallet>
generateNewMnemonic({MnemonicsWordsCount wordsCount = MnemonicsWordsCount.w15}) List<String>